@@ -46,10 +46,8 @@ unsupported_cols = {
     name: col
     for name, col in mixin_cols.items()
     if (
-        isinstance(col, Time)
-        and col.location.shape != ()
-        or isinstance(col, np.ndarray)
-        and col.dtype.kind == "O"
+        (isinstance(col, Time) and col.location.shape != ())
+        or (isinstance(col, np.ndarray) and col.dtype.kind == "O")
         or isinstance(col, u.LogQuantity)
     )
 }
@@ -324,7 +322,7 @@ class TestSingleTable:
     def test_character_as_bytes(self, tmp_path, memmap):
         filename = tmp_path / "test_simple.fts"
         t1 = Table(self.data)
-        t1.write(filename, overwrite=True)
+        t1.write(filename)
         t2 = Table.read(filename, character_as_bytes=False, memmap=memmap)
         t3 = Table.read(filename, character_as_bytes=True, memmap=memmap)
         assert t2["b"].dtype.kind == "U"
@@ -335,6 +333,22 @@ class TestSingleTable:
         del t1, t2, t3
         gc.collect()
 
+    @pytest.mark.parametrize("character_as_bytes", (False, True))
+    def test_strip_spaces(self, tmp_path, character_as_bytes):
+        filename = get_pkg_data_filename("data/tb.fits")
+        t = Table.read(
+            filename, character_as_bytes=character_as_bytes, strip_spaces=True
+        )
+        assert t["c2"].tolist() == ["abc", "xy"]
+
+        t = Table.read(filename, character_as_bytes=character_as_bytes)
+        assert t["c2"].tolist() == ["abc", "xy "]
+
+        t = Table.read(filename, character_as_bytes=character_as_bytes, memmap=True)
+        assert t["c2"].tolist() == ["abc", "xy "]
+        del t
+        gc.collect()
+
     def test_oned_single_element(self, tmp_path):
         filename = tmp_path / "test_oned_single_element.fits"
         table = Table({"x": [[1], [2]]})
@@ -1144,6 +1158,8 @@ def test_zero_length_string_columns_can_be_read_into_table(table_type, tmp_path)
     data = np.array([("", 12)], dtype=[("a", "S"), ("b", "i4")])
     hdu = fits.BinTableHDU(data)
     hdu.writeto(filename)
-    t = table_type.read(filename)
+    # strip_spaces=True causes the array to be converted from dtype('S') to
+    # dtype('S1') so deactivate it to keep the original test
+    t = table_type.read(filename, strip_spaces=False)
     assert t["a"].dtype.itemsize == 0
     assert t["a"].dtype == data["a"].dtype
